# proxyJudge

    # _headers_proxy = ['HTTP_X_FORWARDED_FOR', 'HTTP_X_FORWARDED', 'HTTP_FORWARDED_FOR', 'HTTP_CLIENT_IP', 'HTTP_VIA',
    #                   'HTTP_PROXY_CONNECTION', 'FORWARDED', 'HTTP_FORWARDED_FOR_IP', 'X-PROXY-ID', 'MT-PROXY-ID',
    #                   'X-FORWARDED-FOR', 'FORWARDED-FOR-IP', 'VIA', 'HTTP-VIA', 'HTTP_COMING_FROM', 'HTTP_FORWARDED',
    #                   'HTTP_X_COMING_FROM', 'X-FORWARDED', 'FORWARDED-FOR', 'CLIENT-IP', 'PROXY-CONNECTION']